@@ -207,8 +207,12 @@ fs_msn_connection_dispose (GObject *object)
 
   if (self->polling_thread)
   {
+    GThread *polling_thread = g_thread_ref (self->polling_thread);
     gst_poll_set_flushing (self->poll, TRUE);
-    g_thread_join (self->polling_thread);
+    FS_MSN_CONNECTION_UNLOCK(self);
+    g_thread_join (polling_thread);
+    FS_MSN_CONNECTION_LOCK(self);
+    g_thread_unref (polling_thread);
     self->polling_thread = NULL;
   }
 
@@ -788,7 +792,12 @@ connection_cb (FsMsnConnection *self, FsMsnPollFD *pollfd)
             if (size == 13 && strcmp (str, "connected\r\n\r\n") == 0)
             {
               GST_DEBUG ("connection successful");
-              recv (pollfd->pollfd.fd, str, 13, 0);
+              if (recv (pollfd->pollfd.fd, str, 13, 0) != 13)
+              {
+                GST_WARNING ("Could not read 13 bytes that had previously"
+                    " been peeked at!");
+                goto error;
+              }
               pollfd->status = FS_MSN_STATUS_CONNECTED2;
               pollfd->want_write = TRUE;
               gst_poll_fd_ctl_write (self->poll, &pollfd->pollfd, TRUE);
@@ -830,7 +839,13 @@ connection_cb (FsMsnConnection *self, FsMsnPollFD *pollfd)
             if (size == 13 && strcmp (str, "connected\r\n\r\n") == 0)
             {
               GST_DEBUG ("connection successful");
-              recv (pollfd->pollfd.fd, str, 13, 0);
+              if (recv (pollfd->pollfd.fd, str, 13, 0) != 13)
+              {
+                GST_WARNING ("Could not read 13 bytes that had previously"
+                    " been peeked at!");
+
+                goto error;
+              }
               pollfd->status = FS_MSN_STATUS_SEND_RECEIVE;
               success = TRUE;
             }
