@@ -28,7 +28,6 @@
 
 #include "check-threadsafe.h"
 #include "generic.h"
-#include "fake-filter.h"
 #include "testutils.h"
 
 gint buffer_count[2] = {0, 0};
@@ -38,8 +37,7 @@ GstElement *pipeline = NULL;
 gboolean src_setup[2] = {FALSE, FALSE};
 
 enum {
-  FLAG_NOT_SENDING = 1<<0,
-  FLAG_RECVONLY_FILTER = 1<<1
+  FLAG_NOT_SENDING = 1 << 0
 };
 
 
@@ -108,16 +106,6 @@ _start_pipeline (gpointer user_data)
   return FALSE;
 }
 
-
-static GstElement *
-_get_recvonly_filter (FsTransmitter *trans, guint component, gpointer user_data)
-{
-  if (component == 1)
-    return NULL;
-
-  return gst_element_factory_make ("fsfakefilter", NULL);
-}
-
 static void
 run_multicast_transmitter_test (gint n_parameters, GParameter *params,
                                 gint flags)
@@ -133,12 +121,9 @@ run_multicast_transmitter_test (gint n_parameters, GParameter *params,
   buffer_count[0] = 0;
   buffer_count[1] = 0;
 
-  if (flags & FLAG_NOT_SENDING && flags & FLAG_RECVONLY_FILTER)
+  if (flags & FLAG_NOT_SENDING)
     buffer_count[0] = 20;
 
-  if (flags & FLAG_RECVONLY_FILTER)
-    fail_unless (fs_fake_filter_register ());
-
   loop = g_main_loop_new (NULL, FALSE);
   trans = fs_transmitter_new ("multicast", 2, 0, &error);
 
@@ -153,11 +138,6 @@ run_multicast_transmitter_test (gint n_parameters, GParameter *params,
   g_object_get (trans, "tos", &tos, NULL);
   ts_fail_unless (tos == 2);
 
-  if (flags & FLAG_RECVONLY_FILTER)
-    ts_fail_unless (g_signal_connect (trans, "get-recvonly-filter",
-            G_CALLBACK (_get_recvonly_filter), NULL));
-
-
   pipeline = setup_pipeline (trans, G_CALLBACK (_handoff_handler));
 
   st = fs_transmitter_new_stream_transmitter (trans, NULL, n_parameters, params,
@@ -262,17 +242,9 @@ GST_START_TEST (test_multicasttransmitter_run_local_candidates)
 }
 GST_END_TEST;
 
-GST_START_TEST (test_multicasttransmitter_with_filter)
-{
-  run_multicast_transmitter_test (0, NULL,
-      FLAG_RECVONLY_FILTER);
-}
-GST_END_TEST;
-
 GST_START_TEST (test_multicasttransmitter_sending_half)
 {
-  run_multicast_transmitter_test (0, NULL,
-      FLAG_NOT_SENDING | FLAG_RECVONLY_FILTER);
+  run_multicast_transmitter_test (0, NULL, FLAG_NOT_SENDING);
 }
 GST_END_TEST;
 
@@ -306,10 +278,6 @@ multicasttransmitter_suite (void)
   tcase_add_test (tc_chain, test_multicasttransmitter_run_local_candidates);
   suite_add_tcase (s, tc_chain);
 
-  tc_chain = tcase_create ("multicast_transmitter-with-filter");
-  tcase_add_test (tc_chain, test_multicasttransmitter_with_filter);
-  suite_add_tcase (s, tc_chain);
-
   tc_chain = tcase_create ("multicast_transmitter_sending_half");
   tcase_add_test (tc_chain, test_multicasttransmitter_sending_half);
   suite_add_tcase (s, tc_chain);
