@@ -162,14 +162,14 @@ fs_rawudp_transmitter_register_type (FsPlugin *module)
 
   fs_rawudp_stream_transmitter_register_type (module);
 
-  type = g_type_module_register_type (G_TYPE_MODULE (module),
-      FS_TYPE_TRANSMITTER, "FsRawUdpTransmitter", &info, 0);
+  type = g_type_register_static (FS_TYPE_TRANSMITTER, "FsRawUdpTransmitter",
+      &info, 0);
 
   return type;
 }
 
 
-FS_INIT_PLUGIN (fs_rawudp_transmitter_register_type)
+FS_INIT_PLUGIN (rawudp, transmitter)
 
 static void
 fs_rawudp_transmitter_class_init (FsRawUdpTransmitterClass *klass)
